@@ -19,8 +19,12 @@ import contextlib
 from selenium.webdriver.common.action_chains import ActionChains
 from selenium.webdriver.common.keys import Keys
 from selenium.webdriver.support import expected_conditions as ec
-from selenium.common.exceptions import NoSuchElementException, StaleElementReferenceException,\
-    MoveTargetOutOfBoundsException, ElementNotVisibleException
+from selenium.common.exceptions import (
+    NoSuchElementException,
+    StaleElementReferenceException,
+    MoveTargetOutOfBoundsException,
+    ElementNotVisibleException
+)
 from selenium.webdriver.remote.webelement import WebElement
 
 import basepage.extended_expected_conditions as eec
@@ -138,6 +142,21 @@ class BasePage(object):
         for index, element in enumerate(elements_to_select, start=1):
             self.multi_click(element)
 
+    def move_to_element(self, locator, params=None, timeout=None):
+        """
+        Moves the mouse to specified element.
+        :param locator: locator tuple or WebElement instance
+        :param params: (optional) locator parameters
+        :param timeout: (optional) time to wait for element
+        :return: None
+        """
+        element = locator
+        if not isinstance(element, WebElement):
+            element = self._get(
+                locator, ec.visibility_of_element_located, params, timeout, "Element was never visible!"
+            )
+        ActionChains(self.driver).move_to_element(element).perform()
+
     def select_from_drop_down_by_value(self, locator, value, params=None):
         """
         Select option from drop down widget using value.
@@ -556,7 +575,11 @@ class BasePage(object):
         exp_cond = expected_condition(locator, **kwargs)
         if timeout == 0:
             try:
-                return exp_cond(_driver)
+                exp_cond_result = exp_cond(_driver)
+                # Only return exp_cond_result if it is a list (either empty or will contain one or more WebElements) or
+                # a WebElement - anything else -> let until method handle other types
+                if isinstance(exp_cond_result, (WebElement, list)):
+                    return exp_cond_result
             except NoSuchElementException:
                 return None
 
